@@ -93,7 +93,10 @@ class Users(object):
 
 		# handle success.
 		if success:
-			return r3sponse.success_response(f"Successfully created user [{email}].", {"user":user})
+			return r3sponse.success_response(f"Successfully created user [{email}].", {
+				"user":user,
+				"uid":user.uid,
+			})
 		else:
 			return r3sponse.error_response(f"Failed to create user [{email}].")
 
